Raised when a neither the path nor the on_* attribute is set for a
pagination or table component.
Summary
Functions
Callback implementation for Exception.message/1.
Functions
Callback implementation for Exception.message/1.
Raised when a neither the path nor the on_* attribute is set for a
pagination or table component.
Callback implementation for Exception.message/1.
Callback implementation for Exception.message/1.